@@ -1,7 +1,8 @@
 to_data_frame <- function(x, n = length(x)) {
   data.frame(
     Label = head(attr(x, "labels"), n = n),
-    ID = head(as.vector(x), n = n)
+    ID = head(as.vector(x), n = n),
+    stringsAsFactors = FALSE
   )
 }
 
@@ -15,7 +16,9 @@ print.gho <- function(x, n = 6, ...) {
 
   print(to_data_frame(x, n = n), ...)
 
-  cat(sprintf("...\n\n(Printing %i first elements.)\n", n))
+  if (n < length(x)) {
+    cat(sprintf("...\n\n(Printing %i first elements.)\n", n))
+  }
 
   if (! is.null(attr(x, "attrs"))) {
     names_attr <- names(attr(x, "attrs"))
